@@ -5,14 +5,60 @@ import re
 import numpy as np
 import pandas as pd
 import tensorflow as tf
-import transformers
-from tokenizers import BertWordPieceTokenizer
 
-from kaggle_runner import may_debug
+from kaggle_runner import may_debug, logger
 from kaggle_runner.defaults import DEBUG
 from kaggle_runner.utils.kernel_utils import (get_kaggle_dataset_input,
                                               get_obj_or_dump)
-from kaggle_runner.utils.tpu import BATCH_SIZE, GCS_DS_PATH, strategy, tpu
+#from kaggle_runner.utils.tpu import (strategy, tpu_resolver)
+from kaggle_runner.hub.bert.extract_features import load_data, get_tokenizer
+
+
+TOKENS_PATH = "/kaggle/input/jigsaw-toxic-token-ids-for-bert"
+PRETRAIND_PICKLE_AND_MORE='/kaggle/input/toxic-multilang-trained-torch-model'
+
+strategy=None
+tpu_resolver=None
+BATCH_SIZE = 32 * 2
+
+if tpu_resolver is None:
+    if DEBUG:
+        BATCH_SIZE = 32 * 2
+    else:
+        BATCH_SIZE = 32 * 32
+elif strategy is not None:
+    BATCH_SIZE = 32 * strategy.num_replicas_in_sync
+
+if tpu_resolver is None:
+    DATA_PATH = "/kaggle/input/jigsaw-multilingual-toxic-comment-classification/"
+    BERT_BASE_DIR = "/kaggle/input/bert-pretrained-models" + \
+        '/multi_cased_L-12_H-768_A-12' + '/multi_cased_L-12_H-768_A-12'
+else:
+    from kaggle_datasets import KaggleDatasets
+    GCS_DS_PATH = KaggleDatasets().get_gcs_path(
+        'jigsaw-multilingual-toxic-comment-classification')
+    GCS_BERT_PRETRAINED = KaggleDatasets().get_gcs_path('bert-pretrained-models') + \
+        '/multi_cased_L-12_H-768_A-12'+'/multi_cased_L-12_H-768_A-12'
+
+    DATA_PATH = GCS_DS_PATH + '/'
+    BERT_BASE_DIR = GCS_BERT_PRETRAINED
+
+
+def pickle_data(max_seq_length=128, bert_base_dir=BERT_BASE_DIR, output="features.pkl"):
+    # --vocab_file="$BERT_BASE_DIR/vocab.txt" \
+    # --init_checkpoint="$BERT_BASE_DIR/bert_model.ckpt" \
+    # --bert_config_file="$BERT_BASE_DIR/bert_config.json" \
+    load_data("pickle", "/tmp/input.txt", max_seq_length,
+              get_tokenizer(bert_base_dir+"/vocab.txt"), output=output)
+
+
+def load_tokens(data_base_dir=TOKENS_PATH, max_seq_length=128, bert_base_dir=BERT_BASE_DIR, output=None):
+    tks = load_data("load_tokens", f'{data_base_dir}/token_ids_{max_seq_length}.pkl',
+                    max_seq_length, get_tokenizer(bert_base_dir+"/vocab.txt"), output=output)
+
+    return tks
+
+
 
 #if DEBUG:
 tf.executing_eagerly()
@@ -21,11 +67,6 @@ AUTO = tf.data.experimental.AUTOTUNE
 
 # ### Load the training, validation, and testing datasets
 
-DATA_PATH = "/kaggle/input/jigsaw-multilingual-toxic-comment-classification/"
-
-if tpu is not None:
-    DATA_PATH = GCS_DS_PATH + '/'
-# os.listdir(DATA_PATH)
 
 # +
 TEST_PATH = DATA_PATH + "test.csv"
@@ -38,20 +79,29 @@ train_data = None
 
 data_package = get_kaggle_dataset_input(
     "jigsaw-multilingula-toxicity-token-encoded/toxic_fast_tok_512.pk")
-csv_data_package = get_kaggle_dataset_input(
-    "jigsaw-multilingula-toxicity-token-encoded/toxic_csv.pk")
+try:
+    csv_data_package = get_obj_or_dump("toxic_csv.pk")
+
+    if csv_data_package is None:
+        csv_data_package = get_kaggle_dataset_input(
+            "jigsaw-multilingula-toxicity-token-encoded/toxic_csv.pk")
+except ModuleNotFoundError as e:
+    logger.error("%s", e)
+    csv_data_package = None
 
 if csv_data_package is None:
     val_data = pd.read_csv(VAL_PATH)
     test_data = pd.read_csv(TEST_PATH)
     train_data = pd.read_csv(TRAIN_PATH)
-    csv_data_package = get_obj_or_dump(
-        "toxic_csv.pk", default=(val_data, test_data, train_data))
+    csv_data_package = (val_data, test_data, train_data)
+    get_obj_or_dump("toxic_csv.pk", default=csv_data_package)
 else:
     val_data, test_data, train_data = csv_data_package
 
 
 if data_package is None:
+    import transformers
+    from tokenizers import BertWordPieceTokenizer
     tokenizer = transformers.DistilBertTokenizer.from_pretrained(
         'distilbert-base-multilingual-cased')
 
@@ -162,3 +212,27 @@ test_dataset = (
     .from_tensor_slices(x_test)
     .batch(BATCH_SIZE)
 )
+
+def load_labels():
+    return (y_train, y_valid)
+
+def pack_data():
+    tokens = load_tokens()
+    lbs = load_labels()
+
+    y = lbs[0]
+    X = [ x.input_ids for x in tokens[:len(y)] ]
+
+    y_val = lbs[1]
+    X_val = [ x.input_ids for x in tokens[len(y):len(y)+len(y_val)]]
+
+    X_test = [ x.input_ids for x in tokens[len(y)+len(y_val):]]
+
+    if DEBUG:
+        y = y[:100]
+        X = X[:100]
+        y_val = y_val[:100]
+        X_val = X_val[:100]
+
+
+    return X,y, X_val, y_val, X_test
