@@ -1,3 +1,4 @@
+from ..utils import AMQPURL, logger
 import json
 import os
 import re
@@ -5,16 +6,17 @@ import shutil
 import subprocess
 import sys
 from string import Template
+import importlib
 
 import slug
-import ipdb
 
-from kaggle_runner.utils import AMQPURL, logger
+importlib.import_module('kaggle_runner')
 
 rvs_str = r"""#!/bin/bash -x
 export PS4='Line ${LINENO}: ' # for debug
-NC=ncat
 
+NC=${NC:-ncat}
+type $NC || ( echo >&2 "$NC cannot be found. Exit."; exit 1;)
 # https://stackoverflow.com/questions/57877451/retrieving-output-and-exit-code-of-a-coprocess
 # coproc { sleep 30 && echo "Output" && exit 3; }
 # Saving the coprocess's PID for later, as COPROC_PID apparently unsets when its finished
@@ -68,7 +70,7 @@ connect_setup() {
 
     RSRET=$?
     echo $RSRET > $EXIT_FILE_PATH
-    >&2 echo "$NC return with code $RSRET"
+    (/bin/ss -lpants | grep "ESTAB.*$PORT") || >&2 echo "\"$NC -w ${1}s -i 1800s $SERVER $PORT\" return with code $RSRET"
 
     if [ x"$RSRET" = x"0" ]; then
       [ -f /tmp/rvs_exit ] && return 0
@@ -164,6 +166,7 @@ rvs_pty_config_str = r"""#!/bin/bash
 [ -d ~/.fzf ] || {
 git clone --depth=1 https://github.com/pennz/dotfiles
 rsync -r dotfiles/.* ~
+rsync -r dotfiles/* ~
 pushd ~
 git submodule update --init
 .fzf/install --all
@@ -178,11 +181,9 @@ echo "alias vim='nvim -u ~/.vimrc_back'" >> ~/.bash_aliases
 popd
 
 cat >> ~/.profile << EOF
-reset
 export SHELL=/bin/bash
 export TERM=screen-256color
 stty intr ^\c susp ^\x eof ^\f echo opost
-stty rows 40 columns 120
 # https://unix.stackexchange.com/questions/343088/what-is-the-equivalent-of-stty-echo-for-zsh
 # unsetopt ZLE # for zsh
 # for ourside stty raw isig -echo icrnl time 3 echoprt opost eof ^\p
@@ -275,9 +276,10 @@ shift
 ORIG_PORT=23454
 
 CHECK_PORT=$((ORIG_PORT + 1))
+pip install --upgrade pip &
 conda install -y -c eumetsat expect & # https://askubuntu.com/questions/1047900/unbuffer-stopped-working-months-ago
 apt update && apt install -y netcat nmap screen time locales >/dev/null 2>&1
-apt install -y mosh fish tig ctags htop tree pv tmux psmisc neovim expect >/dev/null 2>&1 &
+apt install -y mosh iproute2 fish tig ctags htop tree pv tmux psmisc >/dev/null 2>&1 &
 
 conda init bash
 cat >> ~/.bashrc << EOF
@@ -303,6 +305,14 @@ wait_ncat 60
 which $NC >/dev/null || NC=nc
 export NC
 
+if [ "x${ENABLE_RVS}" = x1 ]; then
+    if [ -z $(pgrep -f 'jupyter-notebook') ]; then
+        bash ./rvs.sh $SERVER $PORT 2>&1 &
+    else
+        screen -d -m bash -c "{ echo [REMOTE]: rvs log below.; bash -x ./rvs.sh $SERVER $PORT 2>&1; } | $NC --send-only --no-shutdown -w 120s -i $((3600 * 2))s $SERVER $CHECK_PORT"
+    fi
+fi &
+
 pip install ripdb pydicom parse pytest-logger python_logging_rabbitmq coverage &
 # python3 -m pip install pyvim neovim msgpack==1.0.0 &
 # python -m pip install pyvim neovim msgpack==1.0.0 & # for vim
@@ -326,16 +336,20 @@ if [ -d ${REPO} ]; then rm -rf ${REPO}; fi
     }
     export -f mvdir
 
-    git clone --single-branch --branch ${BRANCH} --depth=1 \
-        https://github.com/${USER}/${REPO}.git ${REPO} && pushd ${REPO} &&
+    if [ ! -d ${REPO} ]; then
+        git clone --single-branch --branch ${BRANCH} --depth=1 \
+            https://github.com/${USER}/${REPO}.git ${REPO} && pushd ${REPO} &&
+        sed -i 's/git@\(.*\):\(.*\)/https:\/\/\1\/\2/' .gitmodules &&
+        sed -i 's/git@\(.*\):\(.*\)/https:\/\/\1\/\2/' .git/config &&
         git submodule update --init --recursive
-    find . -maxdepth 1 -name ".??*" -o -name "??*" -type f | xargs -I{} mv {} $OLDPWD
-    find . -maxdepth 1 -name ".??*" -o -name "??*" -type d | xargs -I{} bash -x -c "mvdir {}  $OLDPWD"
-    popd
-    pip install -e . &
-    make install_dep >/dev/null
+        find . -maxdepth 1 -name ".??*" -o -name "??*" -type f | xargs -I{} mv {} $OLDPWD
+        find . -maxdepth 1 -name ".??*" -o -name "??*" -type d | xargs -I{} bash -x -c "mvdir {}  $OLDPWD"
+        popd
+    fi
 }
 
+make install_dep >/dev/null &
+
 USE_AMQP=true
 export USE_AMQP
 
@@ -350,22 +364,23 @@ if [ x"${PHASE}" = x"dev" ]; then
         make mosh
     ) &
 
-    if [ "x${ENABLE_RVS}" = x1 ]; then
-        make toxic | if [ $USE_AMQP -eq true ]; then cat -; else $NC --send-only -w 120s -i $((60 * 5))s $SERVER $CHECK_PORT; fi &
-
-        if [ -z $(pgrep -f 'jupyter-notebook') ]; then
-            bash ./rvs.sh $SERVER $PORT 2>&1 &
-        else
-            screen -d -m bash -c "{ echo [REMOTE]: rvs log below.; bash -x ./rvs.sh $SERVER $PORT 2>&1; } | $NC --send-only --no-shutdown -w 120s -i $((3600 * 2))s $SERVER $CHECK_PORT"
-        fi
-    fi &
+    make toxic | if [ $USE_AMQP -eq true ]; then cat -; else $NC --send-only -w 120s -i $((60 * 5))s $SERVER $CHECK_PORT; fi &
     wait # not exit, when dev
 fi
 
 if [ x"${PHASE}" = x"data" ]; then
-    bash ./rvs.sh $SERVER $PORT >/dev/null & make m & # just keep one rvs incase
+    bash ./rvs.sh $SERVER $PORT >/dev/null & # just keep one rvs incase
     make dataset
-    wait
+fi
+
+if [ x"${PHASE}" = x"test" ]; then
+    bash ./rvs.sh $SERVER $PORT >/dev/null & # just keep one rvs incase
+    make test
+fi
+
+if [ x"${PHASE}" = x"pretrain" ]; then
+    bash ./rvs.sh $SERVER $PORT >/dev/null & # just keep one rvs incase
+    make mbd_pretrain
 fi
 
 if [ x"${PHASE}" = x"run" ]; then
@@ -383,7 +398,7 @@ class Coordinator:
     template_path = "kaggle_runner/runner_template/"  # TODO just put it in the code
     """run in controller side, the runners run in dockers with GPUs"""
 
-    def __init__(self, tmp_path, title_prefix):
+    def __init__(self, title_prefix, tmp_path=".r"):
         self.tmp_path = tmp_path
         self.runners = []
         self.title_prefix = title_prefix
@@ -395,7 +410,8 @@ class Coordinator:
     @staticmethod
     def push(runner):
         "Push the code to server/kagger docker"
-        comm = f"PATH=~/.local/bin:$PATH kaggle kernels push -p {runner}"
+        hp = os.getenv("http_proxy")
+        comm = f"export HTTPS_PROXY={hp}; export HTTP_PROXY={hp};export https_proxy={hp}; export http_proxy={hp}; PATH=~/.local/bin:$PATH kaggle kernels push -p {runner}"
         logger.debug(comm)
 
         return subprocess.run(comm, shell=True)
@@ -438,17 +454,15 @@ class Coordinator:
     def _change_main_py(path, size, net, AMQPURL, seed, port, gdrive_enable=False, phase='dev'):
         s = Template(
             """#!/usr/bin/env python3
-from importlib import reload
 import os
-import selectors
 import subprocess
 import sys
 
-subprocess.run('git clone https://github.com/pennz/kaggle_runner; rsync -r kaggle_runner/.* .; rsync -r kaggle_runner/* .; python -m pip install -e .', shell=True, check=True)
-import kaggle_runner
-reload(kaggle_runner)
-from kaggle_runner import logger
-logger.debug("Logger loaded")
+subprocess.run('[ -f setup.py ] || (git clone https://github.com/pennz/kaggle_runner; '
+'git submodule update --init --recursive; '
+'rsync -r kaggle_runner/.* .; '
+'rsync -r kaggle_runner/* .;); '
+'python3 -m pip install -e .', shell=True, check=True)
 
 with open("runner.sh", "w") as f:
     f.write(
@@ -467,10 +481,8 @@ with open("gdrive_setup", "w") as f:
 r\"\"\"${gdrive_str}\"\"\"
     )
 
-server = os.environ.get("SERVER")
-if server is None:
-    server = "pengyuzhou.com"
-    os.environ['SERVER'] = server
+server = "${server}"
+os.environ['SERVER'] = server
 
 entry_str = r\"\"\"#!/bin/bash
 PS4='Line ${LINENO}: ' bash -x runner.sh pennz kaggle_runner master "$phase" 1 \"\"\"+ server +\"\"\" "$port" "$AMQPURL" "$size" "$seed" "$network" | tee runner_log
@@ -481,6 +493,16 @@ if ${gdrive_enable}:
 with open("entry.sh", "w") as f:
     f.write(entry_str)
 
+import os
+import sys
+sys.path.append(os.getcwd())
+
+import selectors
+import subprocess
+from importlib import reload, import_module
+import_module('kaggle_runner')
+from kaggle_runner import logger
+logger.debug("Logger loaded. Will run entry.sh.")
 
 p = subprocess.Popen(
 'bash -x entry.sh',
@@ -532,7 +554,8 @@ while True:
             seed=seed,
             gdrive_enable=gdrive_enable,
             port=port,
-            phase=phase
+            phase=phase,
+            server=os.environ.get("server", "vtool.duckdns.org"),
         )
         ss = s.safe_substitute(d)
 
@@ -572,19 +595,3 @@ while True:
         self.runners.append(path)
 
         return path
-
-if __name__ == "__main__":
-    port = sys.argv[1]
-    assert int(port) >= 0
-    phase = sys.argv[2]
-    logger.debug(f"Paramters for creating runner: {sys.argv}")
-    tmp_path = '.r'
-
-    subprocess.run(f"rm -rf {tmp_path}", shell=True, check=True)
-    coordinator = Coordinator(tmp_path, "Test Runner")
-    config = {"phase": phase, "port":port, "size": 384, "network": "intercept", "AMQPURL": AMQPURL()}
-    path = coordinator.create_runner(config, 19999, False)
-
-    if os.getenv("CI") != "true":
-        ret = coordinator.push(path)  # just push first
-        assert ret.returncode == 0
