@@ -5,10 +5,11 @@ from kaggle_runner.datasets.bert import (BATCH_SIZE, TRAIN_LEN, train_dataset,
                                          val_data, valid_dataset, x_valid,
                                          y_valid)
 from kaggle_runner.defaults import DEBUG
+from kaggle_runner.utils.visualizer import visualize_model_preds
+
 from kaggle_runner.kernels.bert import (bert_cbs,
                                         build_distilbert_model_singleton,
                                         get_test_result)
-from kaggle_runner.utils.visualizer import visualize_model_preds
 
 
 class Test_distilbert_model:
@@ -17,15 +18,15 @@ class Test_distilbert_model:
         # subprocess.run("make ripdbrv &", shell=True)
 
         if DEBUG:
-            cls.model_distilbert = build_distilbert_model_singleton(140)
+            cls.model = build_distilbert_model_singleton(140)
         else:
-            cls.model_distilbert = build_distilbert_model_singleton(512)
+            cls.model = build_distilbert_model_singleton(512)
 
     @classmethod
     def teardown_class(cls):
         #subprocess.run("pkill -f \"make ripdbrv\"", shell=True)
         try:
-            del cls.model_distilbert
+            del cls.model
         except Exception as e:
             print(e)
         logger.debug("tear down test %s", "Test_distilbert_model")
@@ -42,11 +43,11 @@ class Test_distilbert_model:
 
     def test_summary(self):
         self.setup_class()
-        self.model_distilbert.summary()
+        self.model.summary()
         assert True
 
     def test_fit_adv(self):
-        # self.model_distilbert_dev = build_distilbert_model_singleton(model_type="1st")
+        # self.model_dev = build_distilbert_model_singleton(model_type="1st")
 
         if DEBUG:
             steps = 10
@@ -57,7 +58,7 @@ class Test_distilbert_model:
             epochs = 1
         logger.debug("Every epoch, steps is %s", steps)
 
-        train_history = self.model_distilbert.fit(
+        train_history = self.model.fit(
             train_dataset,
             steps_per_epoch=steps,
             validation_data=valid_dataset,
@@ -69,7 +70,7 @@ class Test_distilbert_model:
 
     def test_visualize(self):
         # model_distilbert.summary()
-        visualize_model_preds(self.model_distilbert, val_data, x_valid, y_valid,
+        visualize_model_preds(self.model, val_data, x_valid, y_valid,
                               indices=[2,3, 5, 6, 7, 8, 1, 4])
 
 if __name__ == "__main__":
